/***************************************************************************
 *   Copyright (C) 2004 by Georges A.Khalil                                *
 *   georges.abou-khalil@polymtl.ca                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <klocale.h>
#include <qtable.h>
#include <qiconview.h>
#include "config.h"
#include "configdlg.h"
#include "configdlggeneral.h"
#include "configdlgbutton.h"
#include "configdlgicons.h"
#include "trayembedlist.h"

configDlg::configDlg(QWidget *parent, const char *name, TrayEmbedList *pList) 
	: KConfigDialog(parent, name, Config::self())
{
	mList = pList;
	configDlgGeneral *lGeneralDlg = new configDlgGeneral();
	addPage(lGeneralDlg, i18n("General"), "configure");
	lButtonDlg = new configDlgButton();
	addPage(lButtonDlg, i18n("Button"), "configure");
	lIconsDlg = new configDlgIcons();
	addPage(lIconsDlg, i18n("Icons"), "configure");
	connect(lIconsDlg->mIconTable, SIGNAL( valueChanged(int,int) ), this, SLOT( slotIconListDirty() ));
	connect(lButtonDlg->mIconView, SIGNAL( selectionChanged () ), this, SLOT( slotButtonIconDirty() ));

	setMinimumSize(600, 400);
}

configDlg::~configDlg()
{
}

void configDlg::show()
{
	mIconListDirty = false;
	mButtonIconDirty = false;
	lIconsDlg->refreshIcons(mList);
	lButtonDlg->refreshIconList();
	KConfigDialog::show();
}

void configDlg::updateSettings()
{
	QTable *lTable = lIconsDlg->mIconTable;

	lTable->setCurrentCell(0, 0);

	if (mIconListDirty) {
		QStringList lTempList;
		for (int i=0;i<lTable->numRows();i++) {
			if (lTable->item(i, 2)->text() == i18n("Always hidden")) {
				lTempList.append(lTable->item(i, 1)->text());
			}
		}
		Config::self()->findItem("HiddenList")->setProperty(lTempList);
		Config::self()->writeConfig();

		lTempList.clear();
		for (int i=0;i<lTable->numRows();i++) {
			if (lTable->item(i, 3)->text() != "0") {
				lTempList.append(lTable->item(i, 1)->text());
				lTempList.append(lTable->item(i, 3)->text());
			}
		}
		Config::self()->findItem("PriorityList")->setProperty(lTempList);
		Config::self()->writeConfig();

		settingsChangedSlot();
		mIconListDirty = false;
	}

	if (mButtonIconDirty) {
		Config::self()->findItem("ButtonIcon")->setProperty(lButtonDlg->mIconView->currentItem()->text());
		Config::self()->writeConfig();
		settingsChangedSlot();
		mButtonIconDirty = false;
	}

	KConfigDialog::updateSettings();
}

void configDlg::slotIconListDirty()
{
	mIconListDirty = true;
	updateButtons();
}

void configDlg::slotButtonIconDirty()
{
	mButtonIconDirty = true;
	updateButtons();
}

bool configDlg::hasChanged()
{
	if (mIconListDirty || mButtonIconDirty) {
		return true;
	}

	return KConfigDialog::hasChanged();
}

