/***************************************************************************
 *   Copyright (C) 2004 by Georges A.Khalil                                *
 *   georges.abou-khalil@polymtl.ca                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <kfiledialog.h> 
#include <kstandarddirs.h>
#include <klocale.h>
#include <qiconview.h>
#include <qpushbutton.h>
#include <qdir.h>
#include <qstringlist.h>

#include "configdlgbutton.h"
#include "config.h"

configDlgButton::configDlgButton(QWidget *parent, const char *name)
 : configDlgButtonBase(parent, name)
{
	connect(mRefreshButton, SIGNAL(clicked()), this, SLOT(refreshIconList()));
	connect(mAddButton, SIGNAL(clicked()), this, SLOT(addIcon()));
	connect(mRemoveButton, SIGNAL(clicked()), this, SLOT(removeIcon()));
}


configDlgButton::~configDlgButton()
{
}

void configDlgButton::refreshIconList()
{
	mIconView->clear();
	QIconViewItem *lDefault1 = new QIconViewItem(mIconView);
	lDefault1->setPixmap(locate("icon","default.kde/16x16/actions/1leftarrow.png"));
	lDefault1->setText(i18n("KDE Default 1"));
	mIconView->insertItem(lDefault1);
	QIconViewItem *lDefault2 = new QIconViewItem(mIconView);
	lDefault2->setPixmap(locate("icon","default.kde/16x16/actions/2leftarrow.png"));
	lDefault2->setText(i18n("KDE Default 2"));
	mIconView->insertItem(lDefault2);
	QString lPath = QDir::homeDirPath() + QString("/.kde/share/apps/kicker");
	QDir lDir;
	QDir().mkdir(lPath);
	lPath += QString("/applet");
	QDir().mkdir(lPath);
	lPath += QString("/systemtray2");
	QDir().mkdir(lPath);
	lPath += QString("/icons");
	QDir().mkdir(lPath);
	lDir.setPath(lPath);
	QStringList lFileList = lDir.entryList("*.png");
	while (lFileList.size() > 0) {
		QIconViewItem *lItem = new QIconViewItem(mIconView);
		lItem->setPixmap(lPath+QString("/")+lFileList.front());
		lItem->setText(lFileList.front());
		mIconView->insertItem(lItem);
		lFileList.pop_front();
	}

	mIconView->setSelected(mIconView->findItem(Config::buttonIcon(), Qt::ExactMatch), true);

	if (!mIconView->currentItem()) {
		mIconView->setSelected(mIconView->firstItem(), true);
	}
}

void configDlgButton::addIcon()
{
	QStringList lIconList = KFileDialog::getOpenFileNames(QDir::homeDirPath(), "image/png", NULL, "Choose an icon");

	while (!lIconList.empty()) {
		QIconViewItem *lItem = new QIconViewItem(mIconView);
		lItem->setPixmap(lIconList.front());
		lItem->setText(QDir(lIconList.front()).dirName());
		mIconView->insertItem(lItem);
		QPixmap lPixmap(lIconList.front());
		lPixmap.save(QDir::homeDirPath() + QString("/.kde/share/apps/kicker/applet/systemtray2/icons/") +
			QDir(lIconList.front()).dirName(), "PNG");
		lIconList.pop_front();
		return;
	}
}

void configDlgButton::removeIcon()
{
	QFile::remove(QDir::homeDirPath() + QString("/.kde/share/apps/kicker/applet/systemtray2/icons/")
		+ mIconView->currentItem()->text());

	refreshIconList();
}

#include "configdlgbutton.moc"
